@@ -78,6 +78,7 @@ def main() -> None:
             "ERROR",
         ],
     )
+    parser.add_argument("--diffable", type=str, help="generate diffable ast traversal")
     args = parser.parse_args()
     os.environ["PY2CFG_SERVER_PORT"] = str(8000 if args.port is None else args.port)
 
@@ -93,8 +94,8 @@ def main() -> None:
     # Run py2cfg interactively along side a debugger.
     if args.debug:
         try:
-            from pudb.debugger import Debugger
-            from pudb.run import main as pudb_main
+            from pudb.debugger import Debugger #type: ignore
+            from pudb.run import main as pudb_main #type: ignore
         except:
             # Once we have a working implementation creating a Spyder plugin should be ez-pz.
             print("pudb not found :(")
@@ -150,7 +151,7 @@ def main() -> None:
     # cfg.build_visual(cfg_name[:-3] + "_cfg", format="png", calls=True, show=False)
     # cfg.build_visual('controlflowgraph', format='png', calls=True, show=False)
     cfg.build_visual(
-        cfg_name[:-3] + "_cfg", format=args.format, calls=args.calls, show=args.show
+        cfg_name[:-3] + "_cfg", format=args.format, calls=args.calls, show=args.show, diffable=args.diffable
     )
 
 
